@@ -139,6 +139,27 @@ RSpec.describe JWT::JWK::EC do
         end
       end
     end
+
+    context 'when the jwk has an invalid alg header' do
+      let(:rsa) { described_class.new(ec_key, alg: 'INVALID') }
+      it 'raises JWT::VerificationError' do
+        expect { rsa.verify(data: data, signature: 'signature') }.to raise_error(JWT::VerificationError, 'Algorithm not supported')
+      end
+    end
+
+    context 'when the jwk has none as the alg parameter' do
+      let(:rsa) { described_class.new(ec_key, alg: 'none') }
+      it 'raises JWT::JWKError' do
+        expect { rsa.verify(data: data, signature: 'signature') }.to raise_error(JWT::JWKError, 'none algorithm usage not supported via JWK')
+      end
+    end
+
+    context 'when the jwk has HS256 as the alg parameter' do
+      let(:rsa) { described_class.new(ec_key, alg: 'HS256') }
+      it 'raises JWT::DecodeError' do
+        expect { rsa.verify(data: data, signature: 'signature') }.to raise_error(JWT::DecodeError, 'HMAC key expected to be a String')
+      end
+    end
   end
 
   describe '.to_openssl_curve' do
